@@ -21,7 +21,7 @@ extern Suite *ebg_test_suite(void);
 
 int main(void)
 {
-	int number_failed = 1;
+	int number_failed;
 
 	Suite *s;
 	SRunner *sr;
@@ -29,13 +29,15 @@ int main(void)
 	s = ebg_test_suite();
 	sr = srunner_create(s);
 
-	if (srunner_fork_status(sr) != CK_FORK) {
-		fprintf(stderr, "Tests assume fork() support");
-	} else {
-		srunner_run_all(sr, CK_NORMAL);
-		number_failed = srunner_ntests_failed(sr);
-		srunner_free(sr);
-	}
+	/* Disable fork to simplify the use of a debugger to diagnose
+	 * test failures. When fork is enabled, the debugger starts
+	 * the parent, but the test runs in a child process. */
+
+	srunner_set_fork_status(sr, CK_NOFORK);
+
+	srunner_run_all(sr, CK_NORMAL);
+	number_failed = srunner_ntests_failed(sr);
+	srunner_free(sr);
 
 	return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
